governance: priorities: [ ] build keys petition keys private key # house key public key # tavern key { approval } { keys } # # These should be regenerateable so that, # if one is compromised, a new one can be # approved by the petition key. # private key public key [ ] nomenclature [ ] genome (blockchain) [ ] [ ] sequence [ ] [ ] strand [ ] { curve, key, combo } { stamp, signature } { approve, authenticators } [ ] start a gadget [ ] approve a transaction topics: lossy compression of ledger state for the purpose of widespread adoption.